@@ -43,14 +43,13 @@
 #include "forward_decls.h"
 #include "buildgraphvisitor.h"
 #include <buildgraph/artifact.h>
-#include <buildgraph/scanresultcache.h>
 #include <language/forward_decls.h>
 
 #include <logging/logger.h>
 #include <tools/buildoptions.h>
 #include <tools/error.h>
 
-#include <QObject>
+#include <QtCore/qobject.h>
 #include <queue>
 
 QT_BEGIN_NAMESPACE
@@ -113,6 +112,7 @@ private:
     void doBuild();
     void prepareAllNodes();
     void prepareArtifact(Artifact *artifact);
+    void setupForBuildingSelectedFiles(const BuildGraphNode *node);
     void prepareReachableNodes();
     void prepareReachableNodes_impl(BuildGraphNode *node);
     void prepareProducts();
@@ -165,19 +165,19 @@ private:
     NodeSet m_roots;
     Leaves m_leaves;
     QList<Artifact *> m_changedSourceArtifacts;
-    ScanResultCache m_scanResultCache;
     InputArtifactScannerContext *m_inputArtifactScanContext;
     ErrorInfo m_error;
     bool m_explicitlyCanceled;
     FileTags m_activeFileTags;
+    FileTags m_tagsOfFilesToConsider;
+    FileTags m_tagsNeededForFilesToConsider;
+    QList<ResolvedProductPtr> m_productsOfFilesToConsider;
     QTimer * const m_cancelationTimer;
     QStringList m_artifactsRemovedFromDisk;
     bool m_partialBuild;
     qint64 m_elapsedTimeRules;
     qint64 m_elapsedTimeScanners;
     qint64 m_elapsedTimeInstalling;
-    const bool m_doTrace;
-    const bool m_doDebug;
 };
 
 } // namespace Internal
